<cfscript>
/**
 * ------------------------------------
 * UDF: checkURLSessionFormat(urlStr)
 * ------------------------------------
 * WORKAROUND for LUCEE 5.3.8.201 bug in 'URLSessionFormat()' function when using JEE/J2EE sessions without
 * accepting any cookies in the client browser.
 * --------------------------------------------------------------------------------------------------------
 * Posted under: https://dev.lucee.org/t/urlsessionformat-does-not-work-when-using-jee-j2ee-sessions/8836/5
 * Bug tracking: https://luceeserver.atlassian.net/browse/LDEV-3707
 *
 * This function checks if cookies are enabled in the client browser and...
 *   EITHER: Returns the original URL (not modified) if cookies are enabled in the client browser.
 *   OR:     Rewrites the URL if cookies are NOT enabled in the client browser.
 *
 * ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 * NOTE: This function can be used with LUCEE and/or ACF.
 *       The code only applies if J2EE/JEE are used in LUCEE and/or ACF.
 * --------------------------------------------------------------------------------------------------------
 * USAGE: You either have to integrate this function directly into your code or you have to do the
 *        integration via <cfinclude> (or any CFC of your choice). Then use 'checkURLSessionFormat(urlStr)'
 *        in your code code instead of LUCEE'S function 'URLSessionFormat(urlStr)'.
 * ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 *
 * @urlStr  The URL string 
 * @return  Returns a string. 
 * @author  Knut Bewersdorff - TripTIX GmbH - Germany 2021
 * @version Version 2.0
 */
// UDF: checkURLSessionFormat(urlStr)
public string function checkURLSessionFormat(required string urlStr) {
	// If the client browser accepts cookies, the 'JSESSIONID' cookie must exist.
	if (isDefined("COOKIE.JSESSIONID")) {
		// Return the original URL string (not modified)
		return urlStr;
	}
	// If the client browser does NOT accept cookies
	else {
		// Check if there are any URL query parameters?
		if (REFindNoCase("\?",urlStr) GT 0) {
			// Append the SessionID in a correct syntax as the first URL path parameter by
			// replacing the question mark (?) with this: ";jsessionid=#session.sessionid#?". 
			// Rewrite the URL string and return it.
			return REReplaceNoCase(urlStr,"\?",";jsessionid=#session.sessionid#?","one");
		}
		// If no URL query parameters were found
		else {
			// Rewrite the URL string and return it
			return urlStr & ";jsessionid=#session.sessionid#";
		}
	}
}
</cfscript>